@@ -1,8 +1,8 @@
 # $File: //member/autrijus/PAR/lib/PAR.pm $ $Author: autrijus $
-# $Revision: #67 $ $Change: 10296 $ $DateTime: 2004/03/02 12:45:32 $ vim: expandtab shiftwidth=4
+# $Revision: #71 $ $Change: 10442 $ $DateTime: 2004/03/28 14:05:12 $ vim: expandtab shiftwidth=4
 
 package PAR;
-$PAR::VERSION = '0.79_99';
+$PAR::VERSION = '0.80_99';
 
 use 5.006;
 use strict;
@@ -15,7 +15,7 @@ PAR - Perl Archive Toolkit
 
 =head1 VERSION
 
-This document describes version 0.79_99 of PAR, released March 3, 2004.
+This document describes version 0.80_99 of PAR, released March 28, 2004.
 
 =head1 SYNOPSIS
 
@@ -434,6 +434,7 @@ sub _set_par_temp {
         my $username = defined(&Win32::LoginName)
             ? &Win32::LoginName()
             : $ENV{USERNAME} || $ENV{USER} || 'SYSTEM';
+        $username =~ s/\W/_/g;
 
         my $stmpdir = File::Spec->catdir($path, "par-$username");
         mkdir $stmpdir, 0755;
@@ -469,15 +470,17 @@ sub _tempfile {
     if ($ENV{PAR_CLEAN} or !@_) {
         require File::Temp;
 
-        # under Win32, the file is created with O_TEMPORARY,
-        # and will be deleted by the C runtime; having File::Temp
-        # delete it has the only effect of giving ugly warnings
-        my ($fh, $filename) = File::Temp::tempfile(
-            DIR     => $par_temp,
-            UNLINK  => ($^O ne 'MSWin32'),
-        ) or die "Cannot create temporary file: $!";
-        binmode($fh);
-        return ($fh, 1, $filename);
+        if (defined &File::Temp::tempfile) {
+            # under Win32, the file is created with O_TEMPORARY,
+            # and will be deleted by the C runtime; having File::Temp
+            # delete it has the only effect of giving ugly warnings
+            my ($fh, $filename) = File::Temp::tempfile(
+                DIR     => $par_temp,
+                UNLINK  => ($^O ne 'MSWin32'),
+            ) or die "Cannot create temporary file: $!";
+            binmode($fh);
+            return ($fh, 1, $filename);
+        }
     }
 
     require File::Spec;
