@@ -1,6 +1,6 @@
 #!/usr/local/bin/perl
 # $File: //member/autrijus/PAR/script/par.pl $ $Author: autrijus $
-# $Revision: #100 $ $Change: 10295 $ $DateTime: 2004/03/02 12:40:26 $ vim: expandtab shiftwidth=4
+# $Revision: #102 $ $Change: 10404 $ $DateTime: 2004/03/17 11:50:19 $ vim: expandtab shiftwidth=4
 
 package __par_pl;
 
@@ -622,13 +622,14 @@ sub _set_par_temp {
         my $username = defined(&Win32::LoginName)
             ? &Win32::LoginName()
             : $ENV{USERNAME} || $ENV{USER} || 'SYSTEM';
+        $username =~ s/\W/_/g;
 
         my $stmpdir = "$path$Config{_delim}par-$username";
         mkdir $stmpdir, 0755;
         if (!$ENV{PAR_CLEAN} and my $mtime = (stat($progname))[9]) {
             my $ctx = eval { require Digest::SHA1; Digest::SHA1->new }
                    || eval { require Digest::MD5; Digest::MD5->new };
-                
+
             if ($ctx and open(my $fh, "<$progname")) {
                 binmode($fh);
                 $ctx->addfile($fh);
@@ -712,7 +713,7 @@ sub _par_init_env {
     if ($ENV{PAR_TEMP}) {
         delete $ENV{PAR_CLEAN};
     }
-    elsif (!$ENV{PAR_CLEAN}) {
+    elsif (!exists $ENV{PAR_GLOBAL_CLEAN}) {
         my $value = substr($par_clean, 12 + length("CLEAN"));
         $ENV{PAR_CLEAN} = $1 if $value =~ /^PAR_CLEAN=(\S+)/;
     }
